// Copyright 2022 Clayton Craft <clayton@craftyguy.net>
// SPDX-License-Identifier: GPL-3.0-or-later

package env

import (
	"testing"
)

func helperBuildEnv(in map[string]string) *EnvStore {
	e := Init()

	for k, v := range in {
		e.Set(k, v)
	}

	return e
}

func TestEnvGet(t *testing.T) {
	tables := []struct {
		name string
		in   map[string]string
	}{
		{
			name: "var echo test",
			in: map[string]string{
				"FOO":      "BAR",
				"BAR":      "foo",
				"1234=abc": "",
			},
		},
	}

	for _, table := range tables {

		t.Run(table.name, func(t *testing.T) {
			e := helperBuildEnv(table.in)
			for k, v := range table.in {
				out, ok := e.Get(k)
				if !ok {
					t.Fatalf("Expected item not found in store: %q", v)
				}
				if v != out {
					t.Fatalf("Expected: %q, got: %q", v, out)
				}
			}
		})
	}
}
