// Copyright 2022 Clayton Craft <clayton@craftyguy.net>
// SPDX-License-Identifier: GPL-3.0-or-later

package misc

import (
	"os"
	"testing"
)

func TestExpandHome(t *testing.T) {
	subtests := []struct {
		name     string
		in       string
		expected string
	}{
		{
			name:     "normal expansion",
			in:       "~/jackfruit/foo.txt",
			expected: "/home/clayton/jackfruit/foo.txt",
		},
		{
			name:     "no expansion",
			in:       "/foo/~/jackfruit/foo.txt",
			expected: "/foo/~/jackfruit/foo.txt",
		},
		{
			name:     "empty",
			in:       "",
			expected: "",
		},
		{
			name:     "no tilde",
			in:       "/home/fig/bazz",
			expected: "/home/fig/bazz",
		},
	}

	for _, subtest := range subtests {

		userHomeDir = func() (string, error) {
			return "/home/clayton", nil
		}
		defer func() { userHomeDir = os.UserHomeDir }()

		t.Run(subtest.name, func(t *testing.T) {

			out := ExpandHome(subtest.in)
			if subtest.expected != out {
				t.Fatalf("Expected: %q, got: %q", subtest.expected, out)
			}
		})
	}
}
