// Copyright 2022 Clayton Craft <clayton@craftyguy.net>
// SPDX-License-Identifier: GPL-3.0-or-later

package xdg

import (
	"os"
	"reflect"
	"sort"
	"testing"
)

func TestDataDirs(t *testing.T) {
	subtests := []struct {
		name     string
		in       string
		expected []string
	}{
		{
			name: "",
			in:   "/usr/share:/usr/local/share",
			expected: []string{
				"/usr/share/superd/services",
				"/usr/local/share/superd/services",
			},
		},
	}

	oldEnv, ok := os.LookupEnv("XDG_DATA_DIRS")
	if ok {
		defer os.Setenv("XDG_DATA_DIRS", oldEnv)
	}

	for _, st := range subtests {
		t.Run(st.name, func(t *testing.T) {
			os.Setenv("XDG_DATA_DIRS", st.in)

			sort.Strings(st.expected)
			out := DataDirs()

			sort.Strings(out)

			if !reflect.DeepEqual(out, st.expected) {
				t.Fatalf("Expected: %q, got: %q", st.expected, out)
			}
		})
	}
}
